@@ -5,7 +5,7 @@ from ..iterators import DatasetIterator
 
 __all__ = ["MultiViewDataset", "MultiViewDatasetIterator"]
 
-MULTI_VIEW_INDEX = "view"
+MULTI_VIEW_INDEX_STR = "view"
 
 
 class MultiViewDataset(BaseDataset, metaclass=ABCMeta):
@@ -14,7 +14,7 @@ class MultiViewDataset(BaseDataset, metaclass=ABCMeta):
 
         def load_view_info():
             views = self._load_view_info()
-            self._update_inventory_index({MULTI_VIEW_INDEX: views})
+            self._update_inventory_index({MULTI_VIEW_INDEX_STR: views})
 
         self.register_preload_func(
             load_view_info, priority=PreloadPriorityOffset.Metadata
@@ -31,4 +31,4 @@ class MultiViewDataset(BaseDataset, metaclass=ABCMeta):
 
 class MultiViewDatasetIterator(DatasetIterator):
     def __init__(self, dataset: MultiViewDataset, **kwargs):
-        super().__init__(dataset, index=MULTI_VIEW_INDEX, **kwargs)
+        super().__init__(dataset, index=MULTI_VIEW_INDEX_STR, **kwargs)
